package Resources;

import java.util.HashMap;
import People.PoliceOfficer;
import People.Student;

// Library defines a whole bunch of useful functions for
// the Problem Set.  Note that all of the methods of Library
// are "static" methods. This means that we can call them without
// creating a new Library object. For example, we would normally 
// have to say:

/*  
 * Library lib = new Library();
 * lib.setup_Cville();
 */

// but because all of our methods are static, we can just say:
// 	Library.setup_Cville();

public class Library {
	
	// Given a direction, return the name of the opposite
	// direction. This is useful for creating two-way connections
	// as we do in the World class.
	public static String direction_opposite(String d) {
		if (d.equals("north")) { return "south"; }
		if (d.equals("south")) { return "north"; }
		if (d.equals("east")) { return "west"; }
		if (d.equals("west")) { return "east"; }
		if (d.equals("enter")) { return "exit"; }
		if (d.equals("exit")) { return "enter"; }
		throw new Error("Bad Direction: " + d);
	}
	
	// setup_CVille creates a fictional world for our adventure
	// game.  You can feel free to create your own world if 
	// you'd like.
	public static World setup_Cville() {
		World cville = new World("Charlottansville");
		
	    //Add some of our favorite places to Charlottansville
		cville.add_place(new Place("Noodles Hall"));	
		cville.add_place(new Place("Witten's Noodles"));
		cville.add_place(new Place("Sture G. Hall"));	
		cville.add_place(new Place("Cabal Hall"));		// Where conspirators scheme
		cville.add_place(new Place("South Green"));		// Emerging terraces		
		cville.add_place(new Place("Bart Statue"));		// Son of Homer
		cville.add_place(new Place("The Green"));		// World famous lawn
		cville.add_place(new Place("U Haul"));			// Rumored to have ghosts of blue devils
		cville.add_place(new Place("The Recursa"));		// Hub of all knowledge and honor
		cville.add_place(new Place("Lambda Dome"));		// Dome of infinite wisdom and ultimate power
		cville.add_place(new Place("University Ave"));	// Its just a street
		cville.add_place(new Place("Cdrs Hill"));		// Home of the Head Transient
		cville.add_place(new Place("Cricket Street"));	// Known for its sticky wickets
		cville.add_place(new Place("Rice Hall")); 		// Big hole in the ground
		cville.add_place(new Place("Oldbrushe Hall"));  // Charlottansville's finest dining establishment	
		cville.add_place(new Place("Old Dorms"));		// Students live here 
		cville.add_place(new Place("New Dorms"));		// Students live here
		cville.add_place(new Place("Cloakner Stadium"));// Sometimes misprounounced "Clockner", but the o: is like in Go:del
		cville.add_place(new Place("Somdergal Library"));// Named for the Univeristy's first president
		cville.add_place(new Place("Jail"));			// Where students caught streaking are sent
		
		// Connect neighboring Places
		cville.connect_both_ways("The Green", "south", "Bart Statue");
		cville.connect_both_ways("Bart Statue", "south", "Cabal Hall");
		cville.connect_both_ways("Cabal Hall", "south", "South Green");

		cville.connect_both_ways("The Green", "north", "The Recursa");
		cville.connect_both_ways("The Recursa", "north", "University Ave");    
		cville.connect_both_ways("University Ave", "north", "Cdrs Hill");
		cville.connect_both_ways("Cdrs Hill", "north", "Cricket Street");
		cville.connect_both_ways("Cricket Street", "north", "U Haul");
		cville.connect_both_ways("U Haul", "west", "Cloakner Stadium");

		cville.connect_both_ways("The Green", "west", "Somdergal Library");
		cville.connect_both_ways("Somdergal Library", "west", "Oldbrushe Hall");
		cville.connect_both_ways("Oldbrushe Hall", "west", "Old Dorms");
		cville.connect_both_ways("Old Dorms", "west", "New Dorms");

		cville.connect_both_ways("Oldbrushe Hall", "south", "Rice Hall");
		cville.connect_both_ways("Rice Hall", "south", "Sture G. Hall");
		cville.connect_one_way("Noodles Hall", "secret passage", "Sture G. Hall");
		cville.connect_one_way("Sture G. Hall", "secret passage", "Noodles Hall");
		cville.connect_both_ways("Noodles Hall", "enter", "Witten's Noodles");
		
		cville.connect_one_way("The Recursa", "enter", "Lambda Dome"); // you can check in, but you can never leave
		cville.connect_both_ways("Lambda Dome", "south", "Lambda Dome");
		cville.connect_both_ways("Lambda Dome", "east", "Lambda Dome");
		
		return cville;
	}
	
	// Here are some different game scenarios you can experiment
	// with if you'd like.  Some of the later ones require that
	// you have completed some of the earlier questions in the
	// Problem Set. 
	public static void play_game_JT() {
		World cville = setup_Cville();
		cville.install_thing(new Person("Evan Davis"), "Cabal Hall");
		cville.install_thing(new Person("Officer Krispy"), "The Green");
	    Person JT = new Person("Jeffus Thomasson");
	    cville.install_thing(JT, "Cdrs Hill");
	    cville.play_interactively(JT);
	}

	public static void play_game_as_APH() {
	    World cville = setup_Cville();
	    // this only works after you have defined the Student and PoliceOfficer classes
	    Student aph = new Student("Alyssa P. Hacker");
	    Student ben = new Student("Ben Bitdiddle");
	    ben.set_restlessness(0.333);
	    PoliceOfficer krumpke = new PoliceOfficer("Officer Krumpke", cville.get_place("Jail"));
	    cville.install_thing(aph, "The Green");    
	    cville.install_thing(ben, "Cdrs Hill");
	    cville.install_thing(krumpke, "Bart Statue");
	    cville.play_interactively(aph);                            
	}
	
	public static void play_game_as_Krumpke() {
	    World cville = setup_Cville();
	    // this only works after you have defined the Student and PoliceOfficer classes
	    Student aph = new Student("Alyssa P. Hacker");
	    aph.set_restlessness(0.5);
	    Student ben = new Student("Ben Bitdiddle");
	    ben.set_restlessness(0.333);
	    PoliceOfficer krumpke = new PoliceOfficer("Officer Krumpke", cville.get_place("Jail"));
	    krumpke.set_restlessness(0);
	    cville.install_thing(aph, "The Green");    
	    cville.install_thing(ben, "Cdrs Hill");
	    cville.install_thing(krumpke, "Bart Statue");
	    cville.play_interactively(krumpke);	
	}
	
	//-----------------------------------------------------------
	// Don't worry if you don't understand this function
	public static PhysicalObject HashMapGet(HashMap<String,PhysicalObject> hm, int index) {
		return (PhysicalObject) hm.values().toArray()[index];
	}
}
