package Resources;

// OwnableObjects extend the concept of a MobileObject
// to include the idea that they have both an owner
// and a location

public class OwnableObject extends MobileObject {
	public Person owner;  // The person that owns the object
	
	// Constructor for an OwnableObject
	public OwnableObject(String name) {
		// Use the constructor for the superclass MobileObject
		super(name);
		// Since the owner hasn't been specified yet,
		// set to null
		owner = null;
	}
	
	// Ownable objects are indeed ownable. This overrides
	// the default is_ownable function defined in SimObject
	public boolean is_ownable() {
		return true;
	}
	
	// We know whether an object is owned based on whether or
	// not its owner is set to null
	public boolean is_owned() {
		return owner!=null;
	}
	
	// Return the owner of the object
	public Person get_owner() {
		return owner;
	}
	
	// Change the owner to a different person
	public void set_owner(Person owner_) {
		owner = owner_;
	}
}
