package Resources;

// SimObject is the superclass for most of the
// classes we use in our simulation including Places,
// MobileObjects, People, etc. 

public class SimObject {
	public String name;  // All SimObjects have a name
	
	// Constructor for SimObjects, its job is to set
	// the name field appropriately
	public SimObject(String name_) {
		name = name_;
	}
	
	// String representation of a SimObject in case
	// we want to print it out
	public String toString() {
		return "<simobject: " + name + ">";
	}
	
	// All SimObjects have is_ownable, is_installed, and
	// is_greetable methods. By default, they always return
	// false, but these functions may be overridden by subclasses.
	// The OwnableObject class, for example, overrides "is_ownable"
	// to always return true.
	public boolean is_ownable() {
		return false;
	}
	public boolean is_installed() {
		return false;
	}
	public boolean is_greetable() {
		return false;
	}
	
	// Have the SimObject print out a message
	public void note(String msg) {
		System.out.println(this.toString() + ": " + msg);
	}
}
